==> idoit-1.10.zip: src/handler/isys_handler_maintenance.class.php <==
<?php
/**
 * i-doit - Documentation and CMDB solution for IT environments
 *
 * This file is part of the i-doit framework. Modify at your own risk.
 *
 * Please visit http://www.i-doit.com/license for a full copyright and license information.
 *
 * @version     1.10
 * @package     i-doit
 * @author      synetics GmbH
 * @copyright   synetics GmbH
 * @url         http://www.i-doit.com
 * @license     http://www.i-doit.com/license
 */
use idoit\Console\Command\Workflow\MaintenanceCommand;
use idoit\Console\IdoitConsoleApplication;
use Symfony\Component\Console\Input\ArrayInput;
use Symfony\Component\Console\Output\ConsoleOutput;

if (!defined("C__MAINT__NOT_DAYS"))
{
    define("C__MAINT__NOT_DAYS", "+0");
} // if

/**
 * i-doit
 *
 * Maintenance handler.
 *
 * @package     i-doit
 * @subpackage  General
 * @author      Dennis Stücken <dstuecken@i-doit.de>
 * @version     1.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 *
 * @deprecated Use MaintenanceCommand instead
 */
class isys_handler_maintenance extends isys_handler
{
    /**
     * @return bool
     */
    public function init()
    {
        global $g_comp_session;

        $application = new IdoitConsoleApplication();
        $application->setAutoExit(false);

        $output = new ConsoleOutput();

        $output->writeln('<error>isys_handler_maintenance is deprecated, please use php console.php system-maintenancecontract instead</error>');

        $commandParams = [
            'command' => 'system-maintenancecontract',
            '--user' => 'loginBefore',
            '--password' => 'loginBefore',
            '--tenantId' => 'loginBefore'
        ];

        /**
         * @var $command \idoit\Console\Command\AbstractCommand
         */
        $command = new MaintenanceCommand();
        $command->setSession($g_comp_session);
        $command->setContainer(\isys_application::instance()->container);
        $command->setAuth(\isys_auth_system::instance());

        $application->add($command);

        $application->run(new ArrayInput($commandParams), $output);

        return true;
    }
} // class

==> idoit-1.12.zip: src/handler/isys_handler_maintenance.class.php <==
<?php

use idoit\Console\IdoitConsoleApplication;
use idoit\Module\Workflow\Console\Command\MaintenanceCommand;
use Symfony\Component\Console\Input\ArrayInput;
use Symfony\Component\Console\Output\ConsoleOutput;

if (!defined("C__MAINT__NOT_DAYS")) {
    define("C__MAINT__NOT_DAYS", "+0");
}

/**
 * i-doit
 *
 * Maintenance handler.
 *
 * @package     i-doit
 * @subpackage  General
 * @author      Dennis Stücken <dstuecken@i-doit.de>
 * @version     1.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 *
 * @deprecated  Use MaintenanceCommand instead
 */
class isys_handler_maintenance extends isys_handler
{
    /**
     * @return bool
     */
    public function init()
    {
        global $g_comp_session;

        $application = new IdoitConsoleApplication();
        $application->setAutoExit(false);

        $output = new ConsoleOutput();

        $output->writeln('<error>isys_handler_maintenance is deprecated, please use php console.php system-maintenancecontract instead</error>');

        $commandParams = [
            'command'    => 'system-maintenancecontract',
            '--user'     => 'loginBefore',
            '--password' => 'loginBefore',
            '--tenantId' => 'loginBefore'
        ];

        /**
         * @var $command \idoit\Console\Command\AbstractCommand
         */
        $command = new MaintenanceCommand();
        $command->setSession($g_comp_session);
        $command->setContainer(\isys_application::instance()->container);
        $command->setAuth(\isys_auth_system::instance());

        $application->add($command);

        $application->run(new ArrayInput($commandParams), $output);

        return true;
    }
}
